@@ -1,8 +1,7 @@
 #! /usr/bin/env python
 # -*- coding: utf-8 -*-
 
-import logging
-logger = logging.getLogger(__name__)
+
 import numpy as np
 
 
